@@ -16,6 +16,9 @@ class HostedModel:
 
 class ProcessorConfig:
     https: bool
+    model_validation: bool
+    ecdsa_verification: bool
+    max_pipes: int
     job_port: int
     hosted_models: List[HostedModel]
 
@@ -23,6 +26,9 @@ class ProcessorConfig:
     def from_dict(data: dict) -> "ProcessorConfig":
         config = ProcessorConfig()
         config.https = data['https']
+        config.model_validation = data['model_validation']
+        config.ecdsa_verification = data['ecdsa_verification']
+        config.max_pipes = data['max_pipes']
         config.job_port = data['job_port']
         config.hosted_models = [HostedModel.from_dict(o) for o in data['hosted_models']]
         return config
